module.exports = {
  extends: [
    // eslint-config-mapbox configs
    "@mapbox/eslint-config-mapbox/react",
    "@mapbox/eslint-config-mapbox/import",
    "@mapbox/eslint-config-mapbox/promise",
    "@mapbox/eslint-config-mapbox/xss",
    "plugin:@mapbox/docs/recommended",
    "plugin:jsx-a11y/recommended",
    "plugin:react-hooks/recommended",
    "plugin:@docusaurus/all",
    "prettier",
  ],
  parser: "@babel/eslint-parser",
  env: {
    browser: true,
  },
  parserOptions: {
    sourceType: "module",
    ecmaFeatures: {
      jsx: true,
    },
    babelOptions: {
      presets: ["@babel/preset-react"],
    },
  },
  globals: {
    MapboxPageShell: true,
    analytics: true,
  },
  plugins: ["es"],
  rules: {
    /* import */
    "import/no-unresolved": [
      "error",
      {
        ignore: [
          "\\.html\\?",
          "^@theme",
          "^@docusaurus",
          "^@site",
          "^@generated",
        ],
      },
    ],
    /* react */
    "react/jsx-uses-react": "error",
    "react/jsx-uses-vars": "error",
    "react/default-props-match-prop-types": "error",
    "react/no-unused-prop-types": "error",
    "react/no-deprecated": "off",
    "react/no-string-refs": "off",
    "react/no-access-state-in-setstate": "off",
    "react/jsx-boolean-value": "off",
    "react/prop-types": "error",
    "react/no-unused-state": "error",
    "react/jsx-no-bind": [
      "error",
      {
        ignoreRefs: true,
        allowArrowFunctions: true,
        allowFunctions: true,
      },
    ],
    "react/prefer-stateless-function": [
      "error",
      { ignorePureComponents: true },
    ],
    /* es overrides */
    "es/no-modules": "off",
    "es/no-block-scoped-variables": "off",
    "es/no-arrow-functions": "off",
    "es/no-classes": "off",
    "es/no-template-literals": "off",
    "es/no-property-shorthands": "off",
    "es/no-destructuring": "off",
    "es/no-default-parameters": "off",
    "es/no-rest-spread-properties": "off",
    "es/no-spread-elements": "off",
    "es/no-dynamic-import": "off",
    /* misc */
    "spaced-comment": "off",
  },
  settings: {
    react: {
      version: "18.2",
    },
  },
};
